@@ -1,30 +1,18 @@
 TMtest <- function(y, trt, n, dferror, mserror, alpha, dms) {
-  Ybar <- tapply(y, trt, mean)
-  Ybar <- sort(Ybar)
-  gap <- Ybar[2:n] - Ybar[1:(n - 1)]
-  auxpos2 <- max(gap)==gap
-  if(length(auxpos2[auxpos2 == T]) > 1){
-    valmax <- which(gap == max(gap))
-    auxpos <- min(c(n - valmax[1], valmax[1]))
-    for(i in valmax[-1]){
-      auxpos <- cbind(auxpos,min(c(n - i, i)))
-    }
-    auxpos <- which.max(auxpos)
-    posmax <- valmax[auxpos]
-  } else{
-    posmax <- as.integer(which.max(Ybar[2:n] - Ybar[1:(n - 1)]))
-  }
+    Ybar <- tapply(y, trt, mean)
+    Ybar <- sort(Ybar)
+  posmax <- as.integer(which.max(Ybar[2:n]-Ybar[1:(n - 1)]))
   if (posmax >= (n - posmax)) {
     Ymean <- mean(Ybar[1:posmax])
   } else
   {
     Ymean <- mean(Ybar[(posmax + 1):n])
   }
-  range <- n
-  pos <- 1
-  col <- 0
-  qobs <- (Ybar[pos] + Ybar[n]) / 2 - Ymean
-  aux <- rep(0, times = n)
+   range <- n
+     pos <- 1
+     col <- 0
+    qobs <- (Ybar[pos] + Ybar[n]) / 2 - Ymean
+     aux <- rep(0, times = n)
   groups <- Ybar
   if ((qobs >= - dms[1]) & (qobs <= dms[1])) aux[1:n] <- 1
   if (!(any(aux == 0))) {
@@ -37,9 +25,9 @@ TMtest <- function(y, trt, n, dferror, mserror, alpha, dms) {
   }
   if (continua1 == TRUE) {
     range <- range - 1
-    pos <- 0
+      pos <- 0
     ncomp <- n - range + 1
-    ct <- 1
+       ct <- 1
     if (range < 2) {
       continua2 <- FALSE
     } else {
@@ -47,29 +35,15 @@ TMtest <- function(y, trt, n, dferror, mserror, alpha, dms) {
     }
     if (continua2 == TRUE) {
       repeat {
-        pos <- pos + 1
+           pos <- pos + 1
         posmax <- as.integer(which.max(Ybar[(pos + 1):(pos + range - 1)]
                                        - Ybar[pos:(pos + range - 2)]))
-        gap <- Ybar[(pos + 1):(pos + range - 1)] - Ybar[pos:(pos + range - 2)]
-        auxpos2 <- max(gap)==gap
-        if(length(auxpos2[auxpos2 == T]) > 1){
-          valmax <- which(gap == max(gap))
-          auxpos <- min(c(range - valmax[1], valmax[1]))
-          for(i in valmax[-1]){
-            auxpos <- cbind(auxpos,min(c(n - i, i)))
-          }
-          auxpos <- which.max(auxpos)
-          posmax <- valmax[auxpos]
-        }else{
-          posmax <- as.integer(which.max(Ybar[(pos + 1):(pos + range - 1)]
-                                         - Ybar[pos:(pos + range - 2)]))
-        }
         if (posmax >= (pos + range - 1 - posmax)) {
           Ymean <- mean(Ybar[pos:(pos+posmax-1)])
         } else {
           Ymean <- mean(Ybar[(pos + posmax):(pos + range - 1)])
         }
-        qobs <- (Ybar[pos] + Ybar[pos+range-1]) / 2 - Ymean
+            qobs <- (Ybar[pos] + Ybar[pos+range-1]) / 2 - Ymean
         aux[1:n] <- 0
         if (((qobs >= - dms[2]) & (qobs <= dms[2]))) {
           aux[pos:(pos + range - 1)] <- 1
@@ -88,15 +62,15 @@ TMtest <- function(y, trt, n, dferror, mserror, alpha, dms) {
         }
         if ((dentro == FALSE) & any(aux == 1)) {
           groups <- cbind(groups, aux)
-          col <- col + 1
+             col <- col + 1
         }
         ct <- ct + 1
         if (ct > ncomp)
         {
           range <- range - 1
-          pos <- 0
+            pos <- 0
           ncomp <- n - range + 1
-          ct <- 1
+             ct <- 1
         }
         if (range < 2) {
           continua2 <- FALSE
@@ -109,4 +83,4 @@ TMtest <- function(y, trt, n, dferror, mserror, alpha, dms) {
   }
   result <- ProcTest(groups)
   return(group.test(result))
-}
\ No newline at end of file
+}
