@@ -7,7 +7,7 @@ if (getRversion() >= "2.15.1") {
   utils::globalVariables(c("brow",
                            "dat", "dat2", "trat", "results", "plot_group",
                            "heat.colors", "results", "dev.new",
-                           "aov"))
+                           "aov", "dispplot"))
 }
 
 
